[![Build Status](https://travis-ci.org/CSnap/Django-pre-post.svg?branch=master)](https://travis-ci.org/CSnap/Django-pre-post)

# Django-pre-post
This Django app provides the ability to create pre-post questions and answers.
